@@ -45,7 +45,7 @@
 			if(!exists("mclapply")){
 				require('multicore')
 			}
-			fitlist = mclapply(1:n, FUN = function(i) arfimafit(spec = multispec@spec[[i]], 
+			fitlist = multicore::mclapply(1:n, FUN = function(i) arfimafit(spec = multispec@spec[[i]], 
 								data = data[, i, drop = FALSE], out.sample = out.sample[i], solver = solver, 
 								solver.control = solver.control, fit.control = fit.control),
 					mc.cores = parallel.control$cores)
@@ -111,7 +111,7 @@
 			if(!exists("mclapply")){
 				require('multicore')
 			}
-			filterlist = mclapply(1:n, FUN = function(i) arfimafilter(data = data[, i, drop = FALSE], spec = specx[[i]], 
+			filterlist = multicore::mclapply(1:n, FUN = function(i) arfimafilter(data = data[, i, drop = FALSE], spec = specx[[i]], 
 								out.sample =  out.sample[i], n.old = n.old), mc.cores = parallel.control$cores)
 		} else{
 			if(!exists("sfLapply")){
@@ -167,7 +167,7 @@
 			if(!exists("mclapply")){
 				require('multicore')
 			}
-			filterlist = mclapply(1:n, FUN = function(i) arfimafilter(spec = speclist@spec[[i]], 
+			filterlist = multicore::mclapply(1:n, FUN = function(i) arfimafilter(spec = speclist@spec[[i]], 
 								data = data[, i, drop = FALSE], out.sample = out.sample[i], n.old = n.old),
 					mc.cores = parallel.control$cores)
 		} else{
@@ -221,7 +221,7 @@
 			if(!exists("mclapply")){
 				require('multicore')
 			}	
-			forecastlist = mclapply(1:n, FUN = function(i) arfimaforecast(fitORspec = multifit@fit[[i]], data = NULL,
+			forecastlist = multicore::mclapply(1:n, FUN = function(i) arfimaforecast(fitORspec = multifit@fit[[i]], data = NULL,
 								n.ahead = n.ahead, n.roll = n.roll, 
 								external.forecasts = external.forecasts, ...), mc.cores = parallel.control$cores)
 		} else{
@@ -283,7 +283,7 @@
 			if(!exists("mclapply")){
 				require('multicore')
 			}
-			forecastlist = mclapply(1:n, FUN = function(i) arfimaforecast(fitORspec = multispec@spec[[i]], data = data[, i, drop = FALSE],
+			forecastlist = multicore::mclapply(1:n, FUN = function(i) arfimaforecast(fitORspec = multispec@spec[[i]], data = data[, i, drop = FALSE],
 								n.ahead = n.ahead, n.roll = n.roll, out.sample = out.sample[i],
 								external.forecasts = external.forecasts, ...), mc.cores = parallel.control$cores)
 		} else{
